@@ -9,7 +9,6 @@
 
 imports callbacks into namespace for convenience
 """
-import types
 from builtins import str
 import configparser
 from configparser import ExtendedInterpolation
@@ -20,9 +19,6 @@ import shutil
 
 import sphinx.builders.text
 import sphinx.writers.text
-from docutils.parsers.rst import Parser as RSTParser
-import docutils.utils
-from docutils.frontend import OptionParser
 
 import clasp.click_callbacks
 from clasp.click_callbacks import *
@@ -118,7 +114,7 @@ def XXX(ctx, arg1, **kwargs):
     pass
 
 
-@main.resultcallback()
+@main.result_callback
 @click.pass_context
 def printconfig(ctx, opts, **kwargs):
     """callback to save config file"""
@@ -139,35 +135,6 @@ def click_ext(click):
     """customize click help messages and bash complete"""
     orig_init = click.core.Option.__init__
 
-    parser = RSTParser()
-    cmpt = (RSTParser,)
-    settings = OptionParser(components=cmpt).get_default_values()
-    settings.tab_size = 4
-    document = docutils.utils.new_document('<rst-doc>', settings)
-
-    app = types.SimpleNamespace(
-            srcdir=None,
-            confdir=None,
-            outdir=None,
-            doctreedir="/",
-            events=None,
-            warn=None,
-            config=types.SimpleNamespace(
-                    text_newlines="native",
-                    text_sectionchars="=",
-                    text_add_secnumbers=False,
-                    text_secnumber_suffix=".",
-                    ),
-            tags=set(),
-            registry=types.SimpleNamespace(
-                    create_translator=lambda s, something,
-                    new_builder: sphinx.writers.text.TextTranslator(
-                            document, new_builder
-                            )
-                    ),
-            )
-    builder = sphinx.builders.text.TextBuilder(app)
-
     def new_init(self, *args, **kwargs):
         orig_init(self, *args, **kwargs)
         if 'show_default' not in kwargs:
@@ -177,22 +144,13 @@ def click_ext(click):
         """modified help text formatter for compatibility with sphinx-click."""
         if self.help:
             formatter.write_paragraph()
-            rst = _process_as_rst(self.help)
+            rst = self.help
             formatter.indent()
             for line in rst.splitlines():
                 formatter.write_text(line)
             formatter.dedent()
             formatter.write_paragraph()
 
-    def _process_as_rst(text):
-        parser.parse(text.replace("*", "\\*"), document)
-        translator = sphinx.writers.text.TextTranslator(document,
-                                                        builder)
-        document.walkabout(translator)
-        rst = translator.body.replace("\n\n", "\n")
-        document.clear()
-        return rst
-
     def format_options(self, ctx, formatter):
         """Writes all the options into the formatter if they exist."""
         opts = []
@@ -222,7 +180,7 @@ def click_ext(click):
                 indent = ' '*formatter.current_indent
                 for opt in opts:
                     formatter.write(f"{indent}{opt[0]}\n")
-                    rst = _process_as_rst(opt[1])
+                    rst = opt[1]
                     formatter.indent()
                     formatter.indent()
                     formatter.width = (sphinx.writers.text.MAXWIDTH +
@@ -232,6 +190,7 @@ def click_ext(click):
                     formatter.dedent()
                     formatter.dedent()
                     formatter.write("\n")
+
     click.core.Option.__init__ = new_init
     click.core.Command.format_help_text = format_help_text
     click.core.Command.format_options = format_options
@@ -274,10 +233,10 @@ def wrap_command():
                     raise
                 except click.exceptions.Exit as ex:
                     if ex.exit_code != 0:
-                        print_except(ex, kwargs['debug'])
+                        print_except(ex, kwargs['debug'], ctx=ctx)
                         raise click.Abort
                 except Exception as ex:
-                    print_except(ex, kwargs['debug'])
+                    print_except(ex, kwargs['debug'], ctx=ctx)
                     raise click.Abort
             return cname, kwargs, ctx
         return handle_call
@@ -361,11 +320,14 @@ def shared_decs(decs):
 def tmp_clean(ctx):
     """remove files placed int temps context object
     (called at end of scripts)"""
-    for i in ctx.obj['temps']:
-        try:
-            os.remove(i)
-        except Exception:
-            pass
+    try:
+        for i in ctx.obj['temps']:
+            try:
+                os.remove(i)
+            except Exception:
+                pass
+    except (KeyError, TypeError):
+        pass
 
 
 def invoke_dependency(ctx, cmd, *args, **kwargs):
@@ -382,7 +344,10 @@ def invoke_dependency(ctx, cmd, *args, **kwargs):
 def read_section(Config, dict1, section, options):
     for option in options:
         try:
-            opt = Config.get(section, option)
+            try:
+                opt = Config.get(section, option)
+            except configparser.InterpolationSyntaxError:
+                opt = Config.get(section, option, raw=True)
             if re.match(r'.+_\d+', option):
                 opto = option.rsplit("_", 1)[0]
                 try:
@@ -394,6 +359,7 @@ def read_section(Config, dict1, section, options):
             else:
                 dict1[option] = opt
         except Exception as ex:
+            print(ex.__class__)
             click.echo("exception on {}! {}".format(option, ex), err=True)
             dict1[option] = None
     return dict1
@@ -620,10 +586,12 @@ def print_config(ctx, opts, outconfig, config, configalias, chain=False):
         f.close()
 
 
-def print_except(ex, debug=False):
+def print_except(ex, debug=False, ctx=None):
     """general human readable exception message"""
     if debug:
         traceback.print_exc()
+    elif ctx is not None:
+        tmp_clean(ctx)
     click.echo("\n**************\n**************", err=True)
     click.echo("Execution failed:", err=True)
     click.echo("{}: {}".format(type(ex).__name__, ex), err=True)
